==> jc-1.4.0.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__24ImageScrollListener.h <==
// class javax.swing.colorchooser.DefaultHSBChooserPanel$ImageScrollListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 682d37286a291ffe javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *);

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/colorchooser/DefaultHSBChooserPanel__24ImageScrollListener.h <==
// class javax.swing.colorchooser.DefaultHSBChooserPanel$ImageScrollListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cb013260ebd95e68 javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener_H_
#define _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs;
typedef struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object;

typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable;
typedef const struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype;

// Constructors
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$method$_init$6dfecddff5585109(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vmethods	javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener;
};

// Vtype
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype {
	_jc_type			type;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs {
	struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs {
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_refs	javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$sub_nonrefs	javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener;
};

// Object instance structure
struct _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$object {
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype	*vtype;
	_jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$vtype _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener$class_object;

#endif	/* _JC_javax_swing_colorchooser_DefaultHSBChooserPanel__24ImageScrollListener_H_ */
